==========================
 Invenio-Formatter v0.2.0
==========================

Invenio-Formatter v0.2.0 was released on August 17, 2015.

About
-----

Invenio module for formatting the bibliographic records.

*This is an experimental development preview release.*

Incompatible changes
--------------------

- Removes unused legacy functions.  (#3)

New features
------------

- Ports `response_formated_records` from Invenio search module.

Installation
------------

   $ pip install invenio-formatter==0.2.0

Documentation
-------------

   http://invenio-formatter.readthedocs.org/en/v0.2.0

Happy hacking and thanks for flying Invenio-Formatter.

| Invenio Development Team
|   Email: info@invenio-software.org
|   IRC: #invenio on irc.freenode.net
|   Twitter: http://twitter.com/inveniosoftware
|   GitHub: https://github.com/inveniosoftware/invenio-formatter
|   URL: http://invenio-software.org
